starmath/inc/node.hxx                   |   18 +++++++++---------
 starmath/inc/parse.hxx                  |    4 ++--
 starmath/inc/visitors.hxx               |   12 ++++++------
 starmath/qa/cppunit/mock-visitor.hxx    |    6 +++---
 starmath/source/mathml/mathmlexport.cxx |    2 +-
 starmath/source/mathml/mathmlimport.cxx |    4 ++--
 starmath/source/mathtype.cxx            |    2 +-
 starmath/source/node.cxx                |   28 ++++++++++++++--------------
 starmath/source/ooxmlexport.cxx         |    2 +-
 starmath/source/ooxmlexport.hxx         |    2 +-
 starmath/source/parse.cxx               |    8 ++++----
 starmath/source/rtfexport.cxx           |    2 +-
 starmath/source/rtfexport.hxx           |    2 +-
 starmath/source/visitors.cxx            |   18 +++++++++---------
 starmath/source/wordexportbase.cxx      |    4 ++--
 starmath/source/wordexportbase.hxx      |    4 ++--
 16 files changed, 59 insertions(+), 59 deletions(-)

New commits:
commit e3ea88c6db5facde01ad0c46d8f9393c4db08c5c
Author:     Andrea Gelmini <andrea.gelm...@gelma.net>
AuthorDate: Thu Feb 4 10:16:38 2021 +0100
Commit:     Andrea Gelmini <andrea.gelm...@gelma.net>
CommitDate: Thu Feb 4 17:11:57 2021 +0100

    Fix typo in code
    
    Here it passed "make build-nocheck" on Linux
    
    Change-Id: I1f6ea440e54f87a90abb1b6e9983443764516e06
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/110373
    Reviewed-by: Julien Nabet <serval2...@yahoo.fr>
    Reviewed-by: Dante DM <dante19031...@gmail.com>
    Reviewed-by: Andrea Gelmini <andrea.gelm...@gelma.net>
    Tested-by: Jenkins

diff --git a/starmath/inc/node.hxx b/starmath/inc/node.hxx
index d0b81737a31d..3c267bb4a9ad 100644
--- a/starmath/inc/node.hxx
+++ b/starmath/inc/node.hxx
@@ -40,7 +40,7 @@
   *             SmVerticalBraceNode                     overbrace; underbrace;
   *             SmOperNode                              sum from to; int from 
to;
   *             SmAlignNode                             text alignment
-  *             SmAttributNode                          font attributes; bold;
+  *             SmAttributeNode                         font attributes; bold;
   *             SmFontNode                              font serif; ...
   *             SmMatrixNode                            matrix
   *         SmVisibleNode                               drawable node
@@ -127,7 +127,7 @@ enum class SmScaleMode
 enum class SmNodeType
 {
 /* 0*/ Table,       Brace,         Bracebody,     Oper,        Align,
-/* 5*/ Attribut,    Font,          UnHor,         BinHor,      BinVer,
+/* 5*/ Attribute,   Font,          UnHor,         BinHor,      BinVer,
 /*10*/ BinDiagonal, SubSup,        Matrix,        Place,       Text,
 /*15*/ Special,     GlyphSpecial,  Math,          Blank,       Error,
 /*20*/ Line,        Expression,    PolyLine,      Root,        RootSymbol,
@@ -225,7 +225,7 @@ public:
      * @param nAttrib
      * @return
      */
-    void SetAttribut(FontAttribute nAttrib);
+    void SetAttribute(FontAttribute nAttrib);
 
     /**
      * Clears the font attribute nAttrib.
@@ -233,7 +233,7 @@ public:
      * @param nAttrib
      * @return
      */
-    void ClearAttribut(FontAttribute nAttrib);
+    void ClearAttribute(FontAttribute nAttrib);
 
     /**
      * Gets the font.
@@ -1902,11 +1902,11 @@ public:
  * 1: Body<BR>
  * None of these may be NULL.
  */
-class SmAttributNode final : public SmStructureNode
+class SmAttributeNode final : public SmStructureNode
 {
 public:
-    explicit SmAttributNode(const SmToken &rNodeToken)
-        : SmStructureNode(SmNodeType::Attribut, rNodeToken, 2) {}
+    explicit SmAttributeNode(const SmToken &rNodeToken)
+        : SmStructureNode(SmNodeType::Attribute, rNodeToken, 2) {}
 
     /**
      * Prepares the SmRect to render.
@@ -1928,14 +1928,14 @@ public:
      * Gets the attribute data.
      * @return attribute data
      */
-    const SmNode* Attribute() const { return const_cast<SmAttributNode 
*>(this)->Attribute(); }
+    const SmNode* Attribute() const { return const_cast<SmAttributeNode 
*>(this)->Attribute(); }
           SmNode* Attribute()       { assert( GetNumSubNodes() == 2 ); return 
GetSubNode( 0 ); }
 
     /**
      * Gets the body data ( the nodes affected by the attribute ).
      * @return body data
      */
-    const SmNode* Body() const { return const_cast<SmAttributNode 
*>(this)->Body(); }
+    const SmNode* Body() const { return const_cast<SmAttributeNode 
*>(this)->Body(); }
           SmNode* Body()      { assert( GetNumSubNodes() == 2 ); return 
GetSubNode( 1 ); }
 };
 
diff --git a/starmath/inc/parse.hxx b/starmath/inc/parse.hxx
index dde0c3454958..b010db941832 100644
--- a/starmath/inc/parse.hxx
+++ b/starmath/inc/parse.hxx
@@ -115,8 +115,8 @@ class SmParser
     std::unique_ptr<SmNode> DoOper();
     std::unique_ptr<SmStructureNode> DoUnOper();
     std::unique_ptr<SmNode> DoAlign(bool bUseExtraSpaces = true);
-    std::unique_ptr<SmStructureNode> DoFontAttribut();
-    std::unique_ptr<SmStructureNode> DoAttribut();
+    std::unique_ptr<SmStructureNode> DoFontAttribute();
+    std::unique_ptr<SmStructureNode> DoAttribute();
     std::unique_ptr<SmStructureNode> DoFont();
     std::unique_ptr<SmStructureNode> DoFontSize();
     std::unique_ptr<SmStructureNode> DoColor();
diff --git a/starmath/inc/visitors.hxx b/starmath/inc/visitors.hxx
index ce2519836844..4929bdd0d3e8 100644
--- a/starmath/inc/visitors.hxx
+++ b/starmath/inc/visitors.hxx
@@ -42,7 +42,7 @@ public:
     virtual void Visit( SmBracebodyNode* pNode ) = 0;
     virtual void Visit( SmOperNode* pNode ) = 0;
     virtual void Visit( SmAlignNode* pNode ) = 0;
-    virtual void Visit( SmAttributNode* pNode ) = 0;
+    virtual void Visit( SmAttributeNode* pNode ) = 0;
     virtual void Visit( SmFontNode* pNode ) = 0;
     virtual void Visit( SmUnHorNode* pNode ) = 0;
     virtual void Visit( SmBinHorNode* pNode ) = 0;
@@ -85,7 +85,7 @@ public:
     void Visit( SmBracebodyNode* pNode ) override;
     void Visit( SmOperNode* pNode ) override;
     void Visit( SmAlignNode* pNode ) override;
-    void Visit( SmAttributNode* pNode ) override;
+    void Visit( SmAttributeNode* pNode ) override;
     void Visit( SmFontNode* pNode ) override;
     void Visit( SmUnHorNode* pNode ) override;
     void Visit( SmBinHorNode* pNode ) override;
@@ -190,7 +190,7 @@ public:
     void Visit( SmBracebodyNode* pNode ) override;
     void Visit( SmOperNode* pNode ) override;
     void Visit( SmAlignNode* pNode ) override;
-    void Visit( SmAttributNode* pNode ) override;
+    void Visit( SmAttributeNode* pNode ) override;
     void Visit( SmFontNode* pNode ) override;
     void Visit( SmUnHorNode* pNode ) override;
     void Visit( SmBinHorNode* pNode ) override;
@@ -307,7 +307,7 @@ public:
     void Visit( SmBracebodyNode* pNode ) override;
     void Visit( SmOperNode* pNode ) override;
     void Visit( SmAlignNode* pNode ) override;
-    void Visit( SmAttributNode* pNode ) override;
+    void Visit( SmAttributeNode* pNode ) override;
     void Visit( SmFontNode* pNode ) override;
     void Visit( SmUnHorNode* pNode ) override;
     void Visit( SmBinHorNode* pNode ) override;
@@ -356,7 +356,7 @@ public:
     void Visit( SmBracebodyNode* pNode ) override;
     void Visit( SmOperNode* pNode ) override;
     void Visit( SmAlignNode* pNode ) override;
-    void Visit( SmAttributNode* pNode ) override;
+    void Visit( SmAttributeNode* pNode ) override;
     void Visit( SmFontNode* pNode ) override;
     void Visit( SmUnHorNode* pNode ) override;
     void Visit( SmBinHorNode* pNode ) override;
@@ -428,7 +428,7 @@ public:
     void Visit( SmBracebodyNode* pNode ) override;
     void Visit( SmOperNode* pNode ) override;
     void Visit( SmAlignNode* pNode ) override;
-    void Visit( SmAttributNode* pNode ) override;
+    void Visit( SmAttributeNode* pNode ) override;
     void Visit( SmFontNode* pNode ) override;
     void Visit( SmUnHorNode* pNode ) override;
     void Visit( SmBinHorNode* pNode ) override;
diff --git a/starmath/qa/cppunit/mock-visitor.hxx 
b/starmath/qa/cppunit/mock-visitor.hxx
index 8dab85336357..ee17cf6f836f 100644
--- a/starmath/qa/cppunit/mock-visitor.hxx
+++ b/starmath/qa/cppunit/mock-visitor.hxx
@@ -52,9 +52,9 @@ public:
         VisitChildren( pNode );
     }
 
-    void Visit( SmAttributNode* pNode ) override {
-        CPPUNIT_ASSERT_EQUAL_MESSAGE("SmAttributNode should have type 
SmNodeType::Attribut",
-                                     SmNodeType::Attribut, pNode->GetType());
+    void Visit( SmAttributeNode* pNode ) override {
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("SmAttributeNode should have type 
SmNodeType::Attribute",
+                                     SmNodeType::Attribute, pNode->GetType());
         VisitChildren( pNode );
     }
 
diff --git a/starmath/source/mathml/mathmlexport.cxx 
b/starmath/source/mathml/mathmlexport.cxx
index 004e83ca1655..56eb78cacab5 100644
--- a/starmath/source/mathml/mathmlexport.cxx
+++ b/starmath/source/mathml/mathmlexport.cxx
@@ -1435,7 +1435,7 @@ void SmXMLExport::ExportNodes(const SmNode* pNode, int 
nLevel)
         case SmNodeType::Oper:
             ExportOperator(pNode, nLevel);
             break;
-        case SmNodeType::Attribut:
+        case SmNodeType::Attribute:
             ExportAttributes(pNode, nLevel);
             break;
         case SmNodeType::Font:
diff --git a/starmath/source/mathml/mathmlimport.cxx 
b/starmath/source/mathml/mathmlimport.cxx
index 061af451bf3a..2da898e31e48 100644
--- a/starmath/source/mathml/mathmlimport.cxx
+++ b/starmath/source/mathml/mathmlimport.cxx
@@ -1689,7 +1689,7 @@ void SmXMLUnderContext_Impl::HandleAccent()
     aToken.eType = TUNDERLINE;
 
     std::unique_ptr<SmNode> pFirst;
-    std::unique_ptr<SmStructureNode> pNode(new SmAttributNode(aToken));
+    std::unique_ptr<SmStructureNode> pNode(new SmAttributeNode(aToken));
     if ((pTest->GetToken().cMathChar & 0x0FFF) == 0x0332)
     {
         pFirst.reset(new SmRectangleNode(aToken));
@@ -1759,7 +1759,7 @@ void SmXMLOverContext_Impl::HandleAccent()
     aToken.cMathChar = '\0';
     aToken.eType = TACUTE;
 
-    std::unique_ptr<SmAttributNode> pNode(new SmAttributNode(aToken));
+    std::unique_ptr<SmAttributeNode> pNode(new SmAttributeNode(aToken));
     SmNodeStack& rNodeStack = GetSmImport().GetNodeStack();
 
     std::unique_ptr<SmNode> pFirst = popOrZero(rNodeStack);
diff --git a/starmath/source/mathtype.cxx b/starmath/source/mathtype.cxx
index 43602a491d03..fc6529e53d6f 100644
--- a/starmath/source/mathtype.cxx
+++ b/starmath/source/mathtype.cxx
@@ -1931,7 +1931,7 @@ void MathType::HandleNodes(SmNode *pNode,int nLevel)
 {
     switch(pNode->GetType())
     {
-        case SmNodeType::Attribut:
+        case SmNodeType::Attribute:
             HandleAttributes(pNode,nLevel);
             break;
         case SmNodeType::Text:
diff --git a/starmath/source/node.cxx b/starmath/source/node.cxx
index e15d72312592..bf56f8dddb75 100644
--- a/starmath/source/node.cxx
+++ b/starmath/source/node.cxx
@@ -49,7 +49,7 @@ return ntype==SmNodeType::Table || ntype==SmNodeType::Line    
    || ntype==SmNo
                                 || ntype==SmNodeType::Matrix      || 
ntype==SmNodeType::Root
                                 || ntype==SmNodeType::Expression  || 
ntype==SmNodeType::Brace
                                 || ntype==SmNodeType::Bracebody   || 
ntype==SmNodeType::Oper
-                                || ntype==SmNodeType::Align       || 
ntype==SmNodeType::Attribut
+                                || ntype==SmNodeType::Align       || 
ntype==SmNodeType::Attribute
                                 || ntype==SmNodeType::Font;
 // clang-format on
 }
@@ -119,7 +119,7 @@ void SmNode::SetColor(const Color& rColor)
 }
 
 
-void SmNode::SetAttribut(FontAttribute nAttrib)
+void SmNode::SetAttribute(FontAttribute nAttrib)
 {
     if (
         (nAttrib == FontAttribute::Bold && !(Flags() & FontChangeMask::Bold)) 
||
@@ -129,11 +129,11 @@ void SmNode::SetAttribut(FontAttribute nAttrib)
         mnAttributes |= nAttrib;
     }
 
-    ForEachNonNull(this, [nAttrib](SmNode 
*pNode){pNode->SetAttribut(nAttrib);});
+    ForEachNonNull(this, [nAttrib](SmNode 
*pNode){pNode->SetAttribute(nAttrib);});
 }
 
 
-void SmNode::ClearAttribut(FontAttribute nAttrib)
+void SmNode::ClearAttribute(FontAttribute nAttrib)
 {
     if (
         (nAttrib == FontAttribute::Bold && !(Flags() & FontChangeMask::Bold)) 
||
@@ -143,7 +143,7 @@ void SmNode::ClearAttribut(FontAttribute nAttrib)
         mnAttributes &= ~nAttrib;
     }
 
-    ForEachNonNull(this, [nAttrib](SmNode 
*pNode){pNode->ClearAttribut(nAttrib);});
+    ForEachNonNull(this, [nAttrib](SmNode 
*pNode){pNode->ClearAttribute(nAttrib);});
 }
 
 
@@ -1633,7 +1633,7 @@ void SmAlignNode::Arrange(OutputDevice &rDev, const 
SmFormat &rFormat)
 /**************************************************************************/
 
 
-void SmAttributNode::Arrange(OutputDevice &rDev, const SmFormat &rFormat)
+void SmAttributeNode::Arrange(OutputDevice &rDev, const SmFormat &rFormat)
 {
     SmNode *pAttr = Attribute(),
            *pBody = Body();
@@ -1658,7 +1658,7 @@ void SmAttributNode::Arrange(OutputDevice &rDev, const 
SmFormat &rFormat)
             break;
         default :
             eVerAlign = RectVerAlign::AttributeHi;
-            if (pBody->GetType() == SmNodeType::Attribut)
+            if (pBody->GetType() == SmNodeType::Attribute)
                 nDist = GetFont().GetFontSize().Height()
                         * rFormat.GetDistance(DIS_ORNAMENTSPACE) / 100;
     }
@@ -1712,10 +1712,10 @@ void SmFontNode::Arrange(OutputDevice &rDev, const 
SmFormat &rFormat)
         case TUNKNOWN : break;  // no assertion on "font <?> <?>"
 
         case TPHANTOM : SetPhantom(true);               break;
-        case TBOLD :    SetAttribut(FontAttribute::Bold);     break;
-        case TITALIC :  SetAttribut(FontAttribute::Italic);   break;
-        case TNBOLD :   ClearAttribut(FontAttribute::Bold);   break;
-        case TNITALIC : ClearAttribut(FontAttribute::Italic); break;
+        case TBOLD :    SetAttribute(FontAttribute::Bold);     break;
+        case TITALIC :  SetAttribute(FontAttribute::Italic);   break;
+        case TNBOLD :   ClearAttribute(FontAttribute::Bold);   break;
+        case TNITALIC : ClearAttribute(FontAttribute::Italic); break;
 
         // Using HTML CSS Level 1 standard
         case TRGB :
@@ -2247,9 +2247,9 @@ void SmSpecialNode::Prepare(const SmFormat &rFormat, 
const SmDocShell &rDocShell
 
     //! see also SmFontStyles::GetStyleName
     if (IsItalic( GetFont() ))
-        SetAttribut(FontAttribute::Italic);
+        SetAttribute(FontAttribute::Italic);
     if (IsBold( GetFont() ))
-        SetAttribut(FontAttribute::Bold);
+        SetAttribute(FontAttribute::Bold);
 
     Flags() |= FontChangeMask::Face;
 
@@ -2421,7 +2421,7 @@ void SmAlignNode::Accept(SmVisitor* pVisitor) {
     pVisitor->Visit(this);
 }
 
-void SmAttributNode::Accept(SmVisitor* pVisitor) {
+void SmAttributeNode::Accept(SmVisitor* pVisitor) {
     pVisitor->Visit(this);
 }
 
diff --git a/starmath/source/ooxmlexport.cxx b/starmath/source/ooxmlexport.cxx
index d7698e2c5aba..ba1b7b34c2da 100644
--- a/starmath/source/ooxmlexport.cxx
+++ b/starmath/source/ooxmlexport.cxx
@@ -193,7 +193,7 @@ void SmOoxmlExport::HandleFractions( const SmNode* pNode, 
int nLevel, const char
     m_pSerializer->endElementNS( XML_m, XML_f );
 }
 
-void SmOoxmlExport::HandleAttribute( const SmAttributNode* pNode, int nLevel )
+void SmOoxmlExport::HandleAttribute( const SmAttributeNode* pNode, int nLevel )
 {
     switch( pNode->Attribute()->GetToken().eType )
     {
diff --git a/starmath/source/ooxmlexport.hxx b/starmath/source/ooxmlexport.hxx
index e5973210b331..019172056ba5 100644
--- a/starmath/source/ooxmlexport.hxx
+++ b/starmath/source/ooxmlexport.hxx
@@ -31,7 +31,7 @@ private:
     void HandleText(const SmNode* pNode, int nLevel) override;
     void HandleFractions(const SmNode* pNode, int nLevel, const char* type) 
override;
     void HandleRoot(const SmRootNode* pNode, int nLevel) override;
-    void HandleAttribute(const SmAttributNode* pNode, int nLevel) override;
+    void HandleAttribute(const SmAttributeNode* pNode, int nLevel) override;
     void HandleOperator(const SmOperNode* pNode, int nLevel) override;
     void HandleSubSupScriptInternal(const SmSubSupNode* pNode, int nLevel, int 
flags) override;
     void HandleMatrix(const SmMatrixNode* pNode, int nLevel) override;
diff --git a/starmath/source/parse.cxx b/starmath/source/parse.cxx
index 340bc465828b..5bb152f68607 100644
--- a/starmath/source/parse.cxx
+++ b/starmath/source/parse.cxx
@@ -1773,7 +1773,7 @@ std::unique_ptr<SmNode> SmParser::DoTerm(bool 
bGroupNumberIdent)
                     bIsAttr = TokenInGroup(TG::Attribute);
                     if (!bIsAttr && !TokenInGroup(TG::FontAttr))
                         break;
-                    aStack.push(bIsAttr ? DoAttribut() : DoFontAttribut());
+                    aStack.push(bIsAttr ? DoAttribute() : DoFontAttribute());
                 }
 
                 auto xFirstNode = DoPower();
@@ -2002,7 +2002,7 @@ std::unique_ptr<SmStructureNode> SmParser::DoUnOper()
     return xSNode;
 }
 
-std::unique_ptr<SmStructureNode> SmParser::DoAttribut()
+std::unique_ptr<SmStructureNode> SmParser::DoAttribute()
 {
     DepthProtect aDepthGuard(m_nParseDepth);
     if (aDepthGuard.TooDeep())
@@ -2010,7 +2010,7 @@ std::unique_ptr<SmStructureNode> SmParser::DoAttribut()
 
     assert(TokenInGroup(TG::Attribute));
 
-    auto xSNode = std::make_unique<SmAttributNode>(m_aCurToken);
+    auto xSNode = std::make_unique<SmAttributeNode>(m_aCurToken);
     std::unique_ptr<SmNode> xAttr;
     SmScaleMode  eScaleMode = SmScaleMode::None;
 
@@ -2042,7 +2042,7 @@ std::unique_ptr<SmStructureNode> SmParser::DoAttribut()
     return xSNode;
 }
 
-std::unique_ptr<SmStructureNode> SmParser::DoFontAttribut()
+std::unique_ptr<SmStructureNode> SmParser::DoFontAttribute()
 {
     DepthProtect aDepthGuard(m_nParseDepth);
     if (aDepthGuard.TooDeep())
diff --git a/starmath/source/rtfexport.cxx b/starmath/source/rtfexport.cxx
index e00e206530ee..575093cfe7cc 100644
--- a/starmath/source/rtfexport.cxx
+++ b/starmath/source/rtfexport.cxx
@@ -88,7 +88,7 @@ void SmRtfExport::HandleFractions(const SmNode* pNode, int 
nLevel, const char* t
     m_pBuffer->append("}"); // mf
 }
 
-void SmRtfExport::HandleAttribute(const SmAttributNode* pNode, int nLevel)
+void SmRtfExport::HandleAttribute(const SmAttributeNode* pNode, int nLevel)
 {
     switch (pNode->Attribute()->GetToken().eType)
     {
diff --git a/starmath/source/rtfexport.hxx b/starmath/source/rtfexport.hxx
index 3a1dd4feb995..b0ba7f5d7a26 100644
--- a/starmath/source/rtfexport.hxx
+++ b/starmath/source/rtfexport.hxx
@@ -28,7 +28,7 @@ private:
     void HandleText(const SmNode* pNode, int nLevel) override;
     void HandleFractions(const SmNode* pNode, int nLevel, const char* type) 
override;
     void HandleRoot(const SmRootNode* pNode, int nLevel) override;
-    void HandleAttribute(const SmAttributNode* pNode, int nLevel) override;
+    void HandleAttribute(const SmAttributeNode* pNode, int nLevel) override;
     void HandleOperator(const SmOperNode* pNode, int nLevel) override;
     void HandleSubSupScriptInternal(const SmSubSupNode* pNode, int nLevel, int 
flags) override;
     void HandleMatrix(const SmMatrixNode* pNode, int nLevel) override;
diff --git a/starmath/source/wordexportbase.cxx 
b/starmath/source/wordexportbase.cxx
index 7f4699dfb952..c4ba615ea1d4 100644
--- a/starmath/source/wordexportbase.cxx
+++ b/starmath/source/wordexportbase.cxx
@@ -25,8 +25,8 @@ void SmWordExportBase::HandleNode(const SmNode* pNode, int 
nLevel)
              "Node: " << nLevel << " " << int(pNode->GetType()) << " " << 
pNode->GetNumSubNodes());
     switch (pNode->GetType())
     {
-        case SmNodeType::Attribut:
-            HandleAttribute(static_cast<const SmAttributNode*>(pNode), nLevel);
+        case SmNodeType::Attribute:
+            HandleAttribute(static_cast<const SmAttributeNode*>(pNode), 
nLevel);
             break;
         case SmNodeType::Text:
             HandleText(pNode, nLevel);
diff --git a/starmath/source/wordexportbase.hxx 
b/starmath/source/wordexportbase.hxx
index af66167a17fb..28bdf8ba4336 100644
--- a/starmath/source/wordexportbase.hxx
+++ b/starmath/source/wordexportbase.hxx
@@ -10,7 +10,7 @@
 #ifndef INCLUDED_STARMATH_SOURCE_WORDEXPORTBASE_HXX
 #define INCLUDED_STARMATH_SOURCE_WORDEXPORTBASE_HXX
 
-class SmAttributNode;
+class SmAttributeNode;
 class SmBinHorNode;
 class SmBraceNode;
 class SmMatrixNode;
@@ -41,7 +41,7 @@ protected:
     void HandleUnaryOperation(const SmUnHorNode* pNode, int nLevel);
     void HandleBinaryOperation(const SmBinHorNode* pNode, int nLevel);
     virtual void HandleRoot(const SmRootNode* pNode, int nLevel) = 0;
-    virtual void HandleAttribute(const SmAttributNode* pNode, int nLevel) = 0;
+    virtual void HandleAttribute(const SmAttributeNode* pNode, int nLevel) = 0;
     virtual void HandleOperator(const SmOperNode* pNode, int nLevel) = 0;
     void HandleSubSupScript(const SmSubSupNode* pNode, int nLevel);
     virtual void HandleSubSupScriptInternal(const SmSubSupNode* pNode, int 
nLevel, int flags) = 0;
_______________________________________________
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to
diff --git a/starmath/source/visitors.cxx b/starmath/source/visitors.cxx
index 3de2d3106322..8d72859c6b7b 100644
--- a/starmath/source/visitors.cxx
+++ b/starmath/source/visitors.cxx
@@ -44,7 +44,7 @@ void SmDefaultingVisitor::Visit( SmAlignNode* pNode )
     DefaultVisit( pNode );
 }
 
-void SmDefaultingVisitor::Visit( SmAttributNode* pNode )
+void SmDefaultingVisitor::Visit( SmAttributeNode* pNode )
 {
     DefaultVisit( pNode );
 }
@@ -297,7 +297,7 @@ void SmDrawingVisitor::Visit( SmAlignNode* pNode )
     DrawChildren( pNode );
 }
 
-void SmDrawingVisitor::Visit( SmAttributNode* pNode )
+void SmDrawingVisitor::Visit( SmAttributeNode* pNode )
 {
     DrawChildren( pNode );
 }
@@ -1501,19 +1501,19 @@ void SmCaretPosGraphBuildingVisitor::Visit( 
SmBraceNode* pNode )
     mpRightMost = right;
 }
 
 /** Build SmCaretPosGraph for SmAttributNode
  *
  * Lines in an SmAttributNode:
  * \code
  *   Attr
  *   Body
  * \endcode
  *
  * There's a body and an attribute, the construction is used for "widehat A", 
where "A" is the body
- * and "^" is the attribute ( note GetScaleMode( ) on SmAttributNode tells how 
the attribute should be
+ * and "^" is the attribute ( note GetScaleMode( ) on SmAttributeNode tells 
how the attribute should be
  * scaled ).
  */
-void SmCaretPosGraphBuildingVisitor::Visit( SmAttributNode* pNode )
+void SmCaretPosGraphBuildingVisitor::Visit( SmAttributeNode* pNode )
 {
     SmNode  *pAttr = pNode->Attribute(),
             *pBody = pNode->Body();
@@ -1671,9 +1671,9 @@ void SmCloningVisitor::Visit( SmAlignNode* pNode )
     mpResult = pClone;
 }
 
-void SmCloningVisitor::Visit( SmAttributNode* pNode )
+void SmCloningVisitor::Visit( SmAttributeNode* pNode )
 {
-    SmAttributNode* pClone = new SmAttributNode( pNode->GetToken( ) );
+    SmAttributeNode* pClone = new SmAttributeNode( pNode->GetToken( ) );
     CloneNodeAttr( pNode, pClone );
     CloneKids( pNode, pClone );
     mpResult = pClone;
@@ -2078,7 +2078,7 @@ void SmNodeToTextVisitor::Visit( SmAlignNode* pNode )
     LineToText( pNode->GetSubNode( 0 ) );
 }
 
-void SmNodeToTextVisitor::Visit( SmAttributNode* pNode )
+void SmNodeToTextVisitor::Visit( SmAttributeNode* pNode )
 {
     Append( pNode->GetToken( ).aText );
     LineToText( pNode->Body() );
@@ -1501,19 +1501,19 @@ void SmCaretPosGraphBuildingVisitor::Visit( 
 }
 
-/** Build SmCaretPosGraph for SmAttributNode
+/** Build SmCaretPosGraph for SmAttributeNode
  *
@@ -1501,19 +1501,19 @@ void SmCaretPosGraphBuildingVisitor::Visit( 
  *
- * Lines in an SmAttributNode:
+ * Lines in an SmAttributeNode:
  * \code
  *   Attr